###########
Likelihoods
###########

Classes defining likelihood functions for use in continuous wave searches.
These likelihood function should be subclasses of the
:class:`bilby.core.likelihood.Likelihood` class.

.. autoclass:: cwinpy.pe.likelihood.TargetedPulsarLikelihood
   :members:


Likelihood references
=====================

.. [1] M. Pitkin, M. Isi, J. Veitch & G. Woan, `arXiv:1705.08978v1
   <https://arxiv.org/abs/1705.08978v1>`_, 2017.